@@ -15,9 +15,8 @@
 #
 # You should have received a copy of the GNU Lesser General Public License along
 # with CubicWeb.  If not, see <http://www.gnu.org/licenses/>.
-"""Twisted request handler for CubicWeb
+"""Twisted request handler for CubicWeb"""
 
-"""
 __docformat__ = "restructuredtext en"
 
 from datetime import datetime
@@ -55,9 +54,9 @@ class CubicWebTwistedRequestAdapter(CubicWebRequestBase):
         return self._twreq.method
 
     def relative_path(self, includeparams=True):
-        """return the normalized path of the request (ie at least relative
-        to the instance's root, but some other normalization may be needed
-        so that the returned path may be used to compare to generated urls
+        """return the normalized path of the request (ie at least relative to
+        the instance's root, but some other normalization may be needed so that
+        the returned path may be used to compare to generated urls
 
         :param includeparams:
            boolean indicating if GET form parameters should be kept in the path
@@ -68,8 +67,8 @@ class CubicWebTwistedRequestAdapter(CubicWebRequestBase):
         return path
 
     def get_header(self, header, default=None, raw=True):
-        """return the value associated with the given input header,
-        raise KeyError if the header is not set
+        """return the value associated with the given input header, raise
+        KeyError if the header is not set
         """
         if raw:
             return self._headers_in.getRawHeaders(header, [default])[0]
@@ -83,32 +82,22 @@ class CubicWebTwistedRequestAdapter(CubicWebRequestBase):
             # Expires header seems to be required by IE7
             self.add_header('Expires', 'Sat, 01 Jan 2000 00:00:00 GMT')
             return
-
         # when using both 'Last-Modified' and 'ETag' response headers
         # (i.e. using respectively If-Modified-Since and If-None-Match request
         # headers, see
         # http://www.w3.org/Protocols/rfc2616/rfc2616-sec13.html#sec13.3.4 for
         # reference
-
-        cached_because_not_modified_since = False
-
         last_modified = self.headers_out.getHeader('last-modified')
         if last_modified is not None:
-            cached_because_not_modified_since = (self._twreq.setLastModified(last_modified)
-                                                 == http.CACHED)
-
-        if not cached_because_not_modified_since:
-            return
-
-        cached_because_etag_is_same = False
+            status = self._twreq.setLastModified(last_modified)
+            if status != http.CACHED:
+                return
         etag = self.headers_out.getRawHeaders('etag')
         if etag is not None:
-            cached_because_etag_is_same = self._twreq.setETag(etag[0]) == http.CACHED
-
-        if cached_because_etag_is_same:
-            response = not_modified_response(self._twreq, self._headers_in)
-            raise DirectResponse(response)
-
+            status = self._twreq.setETag(etag[0])
+            if status == http.CACHED:
+                response = not_modified_response(self._twreq, self._headers_in)
+                raise DirectResponse(response)
         # Expires header seems to be required by IE7
         self.add_header('Expires', 'Sat, 01 Jan 2000 00:00:00 GMT')
 
